==> SingleRBook_1.0.0.tar.gz: SingleRBook/vignettes/book/docs/brain.md <==
---
bibliography: ref.bib
---

# Cross-annotating mouse brains

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Loading the data

We load the classic @zeisel2015brain dataset as our reference.
Here, we'll rely on the fact that the authors have already performed quality control.


```r
library(scRNAseq)
sceZ <- ZeiselBrainData()
```

We compute log-expression values for use in marker detection inside `SingleR()`.


```r
library(scater)
sceZ <- logNormCounts(sceZ)
```

We examine the distribution of labels in this reference.


```r
table(sceZ$level2class)
```

```
## 
##    (none)    Astro1    Astro2   CA1Pyr1   CA1Pyr2 CA1PyrInt   CA2Pyr2   Choroid 
##       189        68        61       380       447        49        41        10 
##   ClauPyr     Epend      Int1     Int10     Int11     Int12     Int13     Int14 
##         5        20        12        21        10        21        15        22 
##     Int15     Int16      Int2      Int3      Int4      Int5      Int6      Int7 
##        18        20        24        10        15        20        22        23 
##      Int8      Int9      Mgl1      Mgl2    Oligo1    Oligo2    Oligo3    Oligo4 
##        26        11        17        16        45        98        87       106 
##    Oligo5    Oligo6     Peric      Pvm1      Pvm2   S1PyrDL  S1PyrL23   S1PyrL4 
##       125       359        21        32        33        81        74        26 
##   S1PyrL5  S1PyrL5a   S1PyrL6  S1PyrL6b    SubPyr     Vend1     Vend2      Vsmc 
##        16        28        39        21        22        32       105        62
```

We load the @tasic2016adult dataset as our test.
While not strictly necessary, we remove putative low-quality cells to simplify later interpretation.


```r
sceT <- TasicBrainData()
sceT <- addPerCellQC(sceT, subsets=list(mito=grep("^mt_", rownames(sceT))))
qc <- quickPerCellQC(colData(sceT), 
    percent_subsets=c("subsets_mito_percent", "altexps_ERCC_percent"))
sceT <- sceT[,which(!qc$discard)]
```

The Tasic dataset was generated using read-based technologies so we need to adjust for the transcript length.


```r
library(AnnotationHub)
mm.db <- AnnotationHub()[["AH73905"]]
mm.exons <- exonsBy(mm.db, by="gene")
mm.exons <- reduce(mm.exons)
mm.len <- sum(width(mm.exons))
mm.symb <- mapIds(mm.db, keys=names(mm.len), keytype="GENEID", column="SYMBOL")
names(mm.len) <- mm.symb

library(scater)
keep <- intersect(names(mm.len), rownames(sceT))
sceT <- sceT[keep,]
assay(sceT, "TPM") <- calculateTPM(sceT, lengths=mm.len[keep])
```

## Applying the annotation

We apply `SingleR()` with Wilcoxon rank sum test-based marker detection to annotate the Tasic dataset with the Zeisel labels.


```r
library(SingleR)
pred.tasic <- SingleR(test=sceT, ref=sceZ, labels=sceZ$level2class, 
    assay.type.test="TPM", de.method="wilcox")
```

We examine the distribution of predicted labels:


```r
table(pred.tasic$labels)
```

```
## 
##   Astro1   Astro2  CA1Pyr2  CA2Pyr2  ClauPyr     Int1    Int10    Int11 
##        1        5        1        3        1      152       98        2 
##    Int12    Int13    Int14    Int15    Int16     Int2     Int3     Int4 
##        9       18       24       16       10      146       94       29 
##     Int6     Int7     Int8     Int9   Oligo1   Oligo2   Oligo3   Oligo4 
##       14        2       35       31        8        1        7        1 
##   Oligo6    Peric  S1PyrDL S1PyrL23  S1PyrL4  S1PyrL5 S1PyrL5a  S1PyrL6 
##        1        1      319       73       16        4      201       46 
## S1PyrL6b   SubPyr 
##       73        5
```

We can also examine the number of discarded cells for each label:


```r
table(Label=pred.tasic$labels,
    Lost=is.na(pred.tasic$pruned.labels))
```

```
##           Lost
## Label      FALSE TRUE
##   Astro1       1    0
##   Astro2       5    0
##   CA1Pyr2      1    0
##   CA2Pyr2      3    0
##   ClauPyr      1    0
##   Int1       152    0
##   Int10       98    0
##   Int11        2    0
##   Int12        9    0
##   Int13       18    0
##   Int14       23    1
##   Int15       16    0
##   Int16       10    0
##   Int2       144    2
##   Int3        94    0
##   Int4        29    0
##   Int6        14    0
##   Int7         2    0
##   Int8        35    0
##   Int9        31    0
##   Oligo1       8    0
##   Oligo2       1    0
##   Oligo3       7    0
##   Oligo4       1    0
##   Oligo6       1    0
##   Peric        1    0
##   S1PyrDL    303   16
##   S1PyrL23    73    0
##   S1PyrL4     16    0
##   S1PyrL5      4    0
##   S1PyrL5a   200    1
##   S1PyrL6     45    1
##   S1PyrL6b    72    1
##   SubPyr       5    0
```

## Diagnostics

We visualize the assignment scores for each label in Figure \@ref(fig:unref-brain-score-heatmap).


```r
plotScoreHeatmap(pred.tasic)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-score-heatmap-1.png" alt="Heatmap of the (normalized) assignment scores for each cell (column) in the Tasic test dataset with respect to each label (row) in the Zeisel reference dataset. The final assignment for each cell is shown in the annotation bar at the top." width="960" />
<p class="caption">(\#fig:unref-brain-score-heatmap)Heatmap of the (normalized) assignment scores for each cell (column) in the Tasic test dataset with respect to each label (row) in the Zeisel reference dataset. The final assignment for each cell is shown in the annotation bar at the top.</p>
</div>

The delta for each cell is visualized in Figure \@ref(fig:unref-brain-delta-dist).


```r
plotDeltaDistribution(pred.tasic)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-delta-dist-1.png" alt="Distributions of the deltas for each cell in the Tasic dataset assigned to each label in the Zeisel dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange." width="960" />
<p class="caption">(\#fig:unref-brain-delta-dist)Distributions of the deltas for each cell in the Tasic dataset assigned to each label in the Zeisel dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange.</p>
</div>

Finally, we visualize the heatmaps of the marker genes for the most frequent label in Figure \@ref(fig:unref-brain-marker-heat).
We could show these for all labels but I wouldn't want to bore you with a parade of large heatmaps. 


```r
library(scater)
collected <- list()
all.markers <- metadata(pred.tasic)$de.genes

sceT <- logNormCounts(sceT)
top.label <- names(sort(table(pred.tasic$labels), decreasing=TRUE))[1]

per.label <- sumCountsAcrossCells(logcounts(sceT), 
    ids=pred.tasic$labels, average=TRUE)
per.label <- assay(per.label)[unique(unlist(all.markers[[top.label]])),]
pheatmap::pheatmap(per.label, main=top.label)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-marker-heat-1.png" alt="Heatmap of log-expression values in the Tasic dataset for all marker genes upregulated in the most frequent label from the Zeisel reference dataset." width="960" />
<p class="caption">(\#fig:unref-brain-marker-heat)Heatmap of log-expression values in the Tasic dataset for all marker genes upregulated in the most frequent label from the Zeisel reference dataset.</p>
</div>

## Comparison to clusters

For comparison, we will perform a quick unsupervised analysis of the Grun dataset.
We model the variances using the spike-in data and we perform graph-based clustering.


```r
library(scran)
decT <- modelGeneVarWithSpikes(sceT, "ERCC")

set.seed(1000100)
sceT <- denoisePCA(sceT, decT, subset.row=getTopHVGs(decT, n=2500))
sceT$cluster <- clusterSNNGraph(sceT, use.dimred="PCA")
```

We do not observe a clean 1:1 mapping between clusters and labels in Figure \@ref(fig:unref-brain-label-clusters),
probably because many of the labels represent closely related cell types that are difficult to distinguish.


```r
tab <- table(cluster=sceT$cluster, label=pred.tasic$labels) 
pheatmap::pheatmap(log10(tab+10))
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-label-clusters-1.png" alt="Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Tasic dataset." width="672" />
<p class="caption">(\#fig:unref-brain-label-clusters)Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Tasic dataset.</p>
</div>

We proceed to the most important part of the analysis.
Yes, that's right, the $t$-SNE plot (Figure \@ref(fig:unref-brain-label-tsne)).


```r
set.seed(101010100)
sceT <- runTSNE(sceT, dimred="PCA")
plotTSNE(sceT, colour_by="cluster", text_colour="red",
    text_by=I(pred.tasic$labels))
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-label-tsne-1.png" alt="$t$-SNE plot of the Tasic dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Zeisel dataset are also placed on the median coordinate across all cells assigned with that label." width="672" />
<p class="caption">(\#fig:unref-brain-label-tsne)$t$-SNE plot of the Tasic dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Zeisel dataset are also placed on the median coordinate across all cells assigned with that label.</p>
</div>

## Session information {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.0.4 (2021-02-15)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.12-books/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.12-books/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_US.UTF-8        LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] parallel  stats4    stats     graphics  grDevices utils     datasets 
[8] methods   base     

other attached packages:
 [1] scran_1.18.5                SingleR_1.4.1              
 [3] ensembldb_2.14.0            AnnotationFilter_1.14.0    
 [5] GenomicFeatures_1.42.2      AnnotationDbi_1.52.0       
 [7] AnnotationHub_2.22.0        BiocFileCache_1.14.0       
 [9] dbplyr_2.1.0                scater_1.18.6              
[11] ggplot2_3.3.3               scRNAseq_2.4.0             
[13] SingleCellExperiment_1.12.0 SummarizedExperiment_1.20.0
[15] Biobase_2.50.0              GenomicRanges_1.42.0       
[17] GenomeInfoDb_1.26.4         IRanges_2.24.1             
[19] S4Vectors_0.28.1            BiocGenerics_0.36.0        
[21] MatrixGenerics_1.2.1        matrixStats_0.58.0         
[23] BiocStyle_2.18.1            rebook_1.0.0               

loaded via a namespace (and not attached):
  [1] igraph_1.2.6                  lazyeval_0.2.2               
  [3] BiocParallel_1.24.1           digest_0.6.27                
  [5] htmltools_0.5.1.1             viridis_0.5.1                
  [7] fansi_0.4.2                   magrittr_2.0.1               
  [9] memoise_2.0.0                 limma_3.46.0                 
 [11] Biostrings_2.58.0             askpass_1.1                  
 [13] prettyunits_1.1.1             colorspace_2.0-0             
 [15] blob_1.2.1                    rappdirs_0.3.3               
 [17] xfun_0.22                     dplyr_1.0.5                  
 [19] callr_3.5.1                   crayon_1.4.1                 
 [21] RCurl_1.98-1.3                jsonlite_1.7.2               
 [23] graph_1.68.0                  glue_1.4.2                   
 [25] gtable_0.3.0                  zlibbioc_1.36.0              
 [27] XVector_0.30.0                DelayedArray_0.16.2          
 [29] BiocSingular_1.6.0            scales_1.1.1                 
 [31] pheatmap_1.0.12               DBI_1.1.1                    
 [33] edgeR_3.32.1                  Rcpp_1.0.6                   
 [35] viridisLite_0.3.0             xtable_1.8-4                 
 [37] progress_1.2.2                dqrng_0.2.1                  
 [39] bit_4.0.4                     rsvd_1.0.3                   
 [41] httr_1.4.2                    RColorBrewer_1.1-2           
 [43] ellipsis_0.3.1                farver_2.1.0                 
 [45] pkgconfig_2.0.3               XML_3.99-0.6                 
 [47] scuttle_1.0.4                 CodeDepends_0.6.5            
 [49] sass_0.3.1                    locfit_1.5-9.4               
 [51] utf8_1.2.1                    labeling_0.4.2               
 [53] tidyselect_1.1.0              rlang_0.4.10                 
 [55] later_1.1.0.1                 munsell_0.5.0                
 [57] BiocVersion_3.12.0            tools_4.0.4                  
 [59] cachem_1.0.4                  generics_0.1.0               
 [61] RSQLite_2.2.4                 ExperimentHub_1.16.0         
 [63] evaluate_0.14                 stringr_1.4.0                
 [65] fastmap_1.1.0                 yaml_2.2.1                   
 [67] processx_3.4.5                knitr_1.31                   
 [69] bit64_4.0.5                   purrr_0.3.4                  
 [71] sparseMatrixStats_1.2.1       mime_0.10                    
 [73] xml2_1.3.2                    biomaRt_2.46.3               
 [75] compiler_4.0.4                beeswarm_0.3.1               
 [77] curl_4.3                      interactiveDisplayBase_1.28.0
 [79] statmod_1.4.35                tibble_3.1.0                 
 [81] bslib_0.2.4                   stringi_1.5.3                
 [83] highr_0.8                     ps_1.6.0                     
 [85] lattice_0.20-41               bluster_1.0.0                
 [87] ProtGenerics_1.22.0           Matrix_1.3-2                 
 [89] vctrs_0.3.6                   pillar_1.5.1                 
 [91] lifecycle_1.0.0               BiocManager_1.30.10          
 [93] jquerylib_0.1.3               BiocNeighbors_1.8.2          
 [95] cowplot_1.1.1                 bitops_1.0-6                 
 [97] irlba_2.3.3                   httpuv_1.5.5                 
 [99] rtracklayer_1.50.0            R6_2.5.0                     
[101] bookdown_0.21                 promises_1.2.0.1             
[103] gridExtra_2.3                 vipor_0.4.5                  
[105] codetools_0.2-18              assertthat_0.2.1             
[107] openssl_1.4.3                 withr_2.4.1                  
[109] GenomicAlignments_1.26.0      Rsamtools_2.6.0              
[111] GenomeInfoDbData_1.2.4        hms_1.0.0                    
[113] grid_4.0.4                    beachmat_2.6.4               
[115] rmarkdown_2.7                 DelayedMatrixStats_1.12.3    
[117] Rtsne_0.15                    shiny_1.6.0                  
[119] ggbeeswarm_0.6.0             
```
</div>

==> SingleRBook_1.4.0.tar.gz: SingleRBook/vignettes/book/docs/brain.md <==
---
bibliography: ref.bib
---

# Cross-annotating mouse brains

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Loading the data

We load the classic @zeisel2015brain dataset as our reference.
Here, we'll rely on the fact that the authors have already performed quality control.


```r
library(scRNAseq)
sceZ <- ZeiselBrainData()
```

We compute log-expression values for use in marker detection inside `SingleR()`.


```r
library(scater)
sceZ <- logNormCounts(sceZ)
```

We examine the distribution of labels in this reference.


```r
table(sceZ$level2class)
```

```
## 
##    (none)    Astro1    Astro2   CA1Pyr1   CA1Pyr2 CA1PyrInt   CA2Pyr2   Choroid 
##       189        68        61       380       447        49        41        10 
##   ClauPyr     Epend      Int1     Int10     Int11     Int12     Int13     Int14 
##         5        20        12        21        10        21        15        22 
##     Int15     Int16      Int2      Int3      Int4      Int5      Int6      Int7 
##        18        20        24        10        15        20        22        23 
##      Int8      Int9      Mgl1      Mgl2    Oligo1    Oligo2    Oligo3    Oligo4 
##        26        11        17        16        45        98        87       106 
##    Oligo5    Oligo6     Peric      Pvm1      Pvm2   S1PyrDL  S1PyrL23   S1PyrL4 
##       125       359        21        32        33        81        74        26 
##   S1PyrL5  S1PyrL5a   S1PyrL6  S1PyrL6b    SubPyr     Vend1     Vend2      Vsmc 
##        16        28        39        21        22        32       105        62
```

We load the @tasic2016adult dataset as our test.
While not strictly necessary, we remove putative low-quality cells to simplify later interpretation.


```r
sceT <- TasicBrainData()
sceT <- addPerCellQC(sceT, subsets=list(mito=grep("^mt_", rownames(sceT))))
qc <- quickPerCellQC(colData(sceT), 
    percent_subsets=c("subsets_mito_percent", "altexps_ERCC_percent"))
sceT <- sceT[,which(!qc$discard)]
```

The Tasic dataset was generated using read-based technologies so we need to adjust for the transcript length.


```r
library(AnnotationHub)
mm.db <- AnnotationHub()[["AH73905"]]
mm.exons <- exonsBy(mm.db, by="gene")
mm.exons <- reduce(mm.exons)
mm.len <- sum(width(mm.exons))
mm.symb <- mapIds(mm.db, keys=names(mm.len), keytype="GENEID", column="SYMBOL")
names(mm.len) <- mm.symb

library(scater)
keep <- intersect(names(mm.len), rownames(sceT))
sceT <- sceT[keep,]
assay(sceT, "TPM") <- calculateTPM(sceT, lengths=mm.len[keep])
```

## Applying the annotation

We apply `SingleR()` with Wilcoxon rank sum test-based marker detection to annotate the Tasic dataset with the Zeisel labels.


```r
library(SingleR)
pred.tasic <- SingleR(test=sceT, ref=sceZ, labels=sceZ$level2class, 
    assay.type.test="TPM", de.method="wilcox")
```

We examine the distribution of predicted labels:


```r
table(pred.tasic$labels)
```

```
## 
##   Astro1   Astro2  CA1Pyr2  CA2Pyr2  ClauPyr     Int1    Int10    Int11 
##        1        5        1        3        1      152       98        2 
##    Int12    Int13    Int14    Int15    Int16     Int2     Int3     Int4 
##        9       18       24       16       10      146       94       29 
##     Int6     Int7     Int8     Int9   Oligo1   Oligo2   Oligo3   Oligo4 
##       14        2       35       31        8        1        7        1 
##   Oligo6    Peric  S1PyrDL S1PyrL23  S1PyrL4  S1PyrL5 S1PyrL5a  S1PyrL6 
##        1        1      319       73       16        4      201       46 
## S1PyrL6b   SubPyr 
##       73        5
```

We can also examine the number of discarded cells for each label:


```r
table(Label=pred.tasic$labels,
    Lost=is.na(pred.tasic$pruned.labels))
```

```
##           Lost
## Label      FALSE TRUE
##   Astro1       1    0
##   Astro2       5    0
##   CA1Pyr2      1    0
##   CA2Pyr2      3    0
##   ClauPyr      1    0
##   Int1       152    0
##   Int10       98    0
##   Int11        2    0
##   Int12        9    0
##   Int13       18    0
##   Int14       23    1
##   Int15       16    0
##   Int16       10    0
##   Int2       144    2
##   Int3        94    0
##   Int4        29    0
##   Int6        14    0
##   Int7         2    0
##   Int8        35    0
##   Int9        31    0
##   Oligo1       8    0
##   Oligo2       1    0
##   Oligo3       7    0
##   Oligo4       1    0
##   Oligo6       1    0
##   Peric        1    0
##   S1PyrDL    303   16
##   S1PyrL23    73    0
##   S1PyrL4     16    0
##   S1PyrL5      4    0
##   S1PyrL5a   200    1
##   S1PyrL6     45    1
##   S1PyrL6b    72    1
##   SubPyr       5    0
```

## Diagnostics

We visualize the assignment scores for each label in Figure \@ref(fig:unref-brain-score-heatmap).


```r
plotScoreHeatmap(pred.tasic)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-score-heatmap-1.png" alt="Heatmap of the (normalized) assignment scores for each cell (column) in the Tasic test dataset with respect to each label (row) in the Zeisel reference dataset. The final assignment for each cell is shown in the annotation bar at the top." width="960" />
<p class="caption">(\#fig:unref-brain-score-heatmap)Heatmap of the (normalized) assignment scores for each cell (column) in the Tasic test dataset with respect to each label (row) in the Zeisel reference dataset. The final assignment for each cell is shown in the annotation bar at the top.</p>
</div>

The delta for each cell is visualized in Figure \@ref(fig:unref-brain-delta-dist).


```r
plotDeltaDistribution(pred.tasic)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-delta-dist-1.png" alt="Distributions of the deltas for each cell in the Tasic dataset assigned to each label in the Zeisel dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange." width="960" />
<p class="caption">(\#fig:unref-brain-delta-dist)Distributions of the deltas for each cell in the Tasic dataset assigned to each label in the Zeisel dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange.</p>
</div>

Finally, we visualize the heatmaps of the marker genes for the most frequent label in Figure \@ref(fig:unref-brain-marker-heat).
We could show these for all labels but I wouldn't want to bore you with a parade of large heatmaps. 


```r
library(scater)
collected <- list()
all.markers <- metadata(pred.tasic)$de.genes

sceT <- logNormCounts(sceT)
top.label <- names(sort(table(pred.tasic$labels), decreasing=TRUE))[1]

per.label <- sumCountsAcrossCells(logcounts(sceT), 
    ids=pred.tasic$labels, average=TRUE)
per.label <- assay(per.label)[unique(unlist(all.markers[[top.label]])),]
pheatmap::pheatmap(per.label, main=top.label)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-marker-heat-1.png" alt="Heatmap of log-expression values in the Tasic dataset for all marker genes upregulated in the most frequent label from the Zeisel reference dataset." width="960" />
<p class="caption">(\#fig:unref-brain-marker-heat)Heatmap of log-expression values in the Tasic dataset for all marker genes upregulated in the most frequent label from the Zeisel reference dataset.</p>
</div>

## Comparison to clusters

For comparison, we will perform a quick unsupervised analysis of the Grun dataset.
We model the variances using the spike-in data and we perform graph-based clustering.


```r
library(scran)
decT <- modelGeneVarWithSpikes(sceT, "ERCC")

set.seed(1000100)
sceT <- denoisePCA(sceT, decT, subset.row=getTopHVGs(decT, n=2500))

library(bluster)
sceT$cluster <- clusterRows(reducedDim(sceT, "PCA"), NNGraphParam())
```

We do not observe a clean 1:1 mapping between clusters and labels in Figure \@ref(fig:unref-brain-label-clusters),
probably because many of the labels represent closely related cell types that are difficult to distinguish.


```r
tab <- table(cluster=sceT$cluster, label=pred.tasic$labels) 
pheatmap::pheatmap(log10(tab+10))
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-label-clusters-1.png" alt="Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Tasic dataset." width="672" />
<p class="caption">(\#fig:unref-brain-label-clusters)Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Tasic dataset.</p>
</div>

We proceed to the most important part of the analysis.
Yes, that's right, the $t$-SNE plot (Figure \@ref(fig:unref-brain-label-tsne)).


```r
set.seed(101010100)
sceT <- runTSNE(sceT, dimred="PCA")
plotTSNE(sceT, colour_by="cluster", text_colour="red",
    text_by=I(pred.tasic$labels))
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-label-tsne-1.png" alt="$t$-SNE plot of the Tasic dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Zeisel dataset are also placed on the median coordinate across all cells assigned with that label." width="672" />
<p class="caption">(\#fig:unref-brain-label-tsne)$t$-SNE plot of the Tasic dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Zeisel dataset are also placed on the median coordinate across all cells assigned with that label.</p>
</div>

## Session information {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.1.1 (2021-08-10)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.3 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.14-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.14-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] bluster_1.4.0               scran_1.22.0               
 [3] SingleR_1.8.0               ensembldb_2.18.0           
 [5] AnnotationFilter_1.18.0     GenomicFeatures_1.46.0     
 [7] AnnotationDbi_1.56.0        AnnotationHub_3.2.0        
 [9] BiocFileCache_2.2.0         dbplyr_2.1.1               
[11] scater_1.22.0               ggplot2_3.3.5              
[13] scuttle_1.4.0               scRNAseq_2.7.2             
[15] SingleCellExperiment_1.16.0 SummarizedExperiment_1.24.0
[17] Biobase_2.54.0              GenomicRanges_1.46.0       
[19] GenomeInfoDb_1.30.0         IRanges_2.28.0             
[21] S4Vectors_0.32.0            BiocGenerics_0.40.0        
[23] MatrixGenerics_1.6.0        matrixStats_0.61.0         
[25] BiocStyle_2.22.0            rebook_1.4.0               

loaded via a namespace (and not attached):
  [1] igraph_1.2.7                  lazyeval_0.2.2               
  [3] BiocParallel_1.28.0           digest_0.6.28                
  [5] htmltools_0.5.2               viridis_0.6.2                
  [7] fansi_0.5.0                   magrittr_2.0.1               
  [9] memoise_2.0.0                 ScaledMatrix_1.2.0           
 [11] cluster_2.1.2                 limma_3.50.0                 
 [13] Biostrings_2.62.0             prettyunits_1.1.1            
 [15] colorspace_2.0-2              blob_1.2.2                   
 [17] rappdirs_0.3.3                ggrepel_0.9.1                
 [19] xfun_0.27                     dplyr_1.0.7                  
 [21] crayon_1.4.1                  RCurl_1.98-1.5               
 [23] jsonlite_1.7.2                graph_1.72.0                 
 [25] glue_1.4.2                    gtable_0.3.0                 
 [27] zlibbioc_1.40.0               XVector_0.34.0               
 [29] DelayedArray_0.20.0           BiocSingular_1.10.0          
 [31] scales_1.1.1                  pheatmap_1.0.12              
 [33] edgeR_3.36.0                  DBI_1.1.1                    
 [35] Rcpp_1.0.7                    viridisLite_0.4.0            
 [37] xtable_1.8-4                  progress_1.2.2               
 [39] dqrng_0.3.0                   bit_4.0.4                    
 [41] rsvd_1.0.5                    metapod_1.2.0                
 [43] httr_1.4.2                    RColorBrewer_1.1-2           
 [45] dir.expiry_1.2.0              ellipsis_0.3.2               
 [47] farver_2.1.0                  pkgconfig_2.0.3              
 [49] XML_3.99-0.8                  CodeDepends_0.6.5            
 [51] sass_0.4.0                    locfit_1.5-9.4               
 [53] utf8_1.2.2                    labeling_0.4.2               
 [55] tidyselect_1.1.1              rlang_0.4.12                 
 [57] later_1.3.0                   munsell_0.5.0                
 [59] BiocVersion_3.14.0            tools_4.1.1                  
 [61] cachem_1.0.6                  generics_0.1.1               
 [63] RSQLite_2.2.8                 ExperimentHub_2.2.0          
 [65] evaluate_0.14                 stringr_1.4.0                
 [67] fastmap_1.1.0                 yaml_2.2.1                   
 [69] knitr_1.36                    bit64_4.0.5                  
 [71] purrr_0.3.4                   KEGGREST_1.34.0              
 [73] sparseMatrixStats_1.6.0       mime_0.12                    
 [75] xml2_1.3.2                    biomaRt_2.50.0               
 [77] compiler_4.1.1                beeswarm_0.4.0               
 [79] filelock_1.0.2                curl_4.3.2                   
 [81] png_0.1-7                     interactiveDisplayBase_1.32.0
 [83] statmod_1.4.36                tibble_3.1.5                 
 [85] bslib_0.3.1                   stringi_1.7.5                
 [87] highr_0.9                     lattice_0.20-45              
 [89] ProtGenerics_1.26.0           Matrix_1.3-4                 
 [91] vctrs_0.3.8                   pillar_1.6.4                 
 [93] lifecycle_1.0.1               BiocManager_1.30.16          
 [95] jquerylib_0.1.4               BiocNeighbors_1.12.0         
 [97] cowplot_1.1.1                 bitops_1.0-7                 
 [99] irlba_2.3.3                   httpuv_1.6.3                 
[101] rtracklayer_1.54.0            R6_2.5.1                     
[103] BiocIO_1.4.0                  bookdown_0.24                
[105] promises_1.2.0.1              gridExtra_2.3                
[107] vipor_0.4.5                   codetools_0.2-18             
[109] assertthat_0.2.1              rjson_0.2.20                 
[111] withr_2.4.2                   GenomicAlignments_1.30.0     
[113] Rsamtools_2.10.0              GenomeInfoDbData_1.2.7       
[115] parallel_4.1.1                hms_1.1.1                    
[117] grid_4.1.1                    beachmat_2.10.0              
[119] rmarkdown_2.11                DelayedMatrixStats_1.16.0    
[121] Rtsne_0.15                    shiny_1.7.1                  
[123] ggbeeswarm_0.6.0              restfulr_0.0.13              
```
</div>
